@@ -1,7 +1,7 @@
 /* BayesX - Software for Bayesian Inference in
 Structured Additive Regression Models.
-Copyright (C) 2011  Christiane Belitz, Andreas Brezger,
-Thomas Kneib, Stefan Lang, Nikolaus Umlauf
+Copyright (C) 2019 Christiane Belitz, Andreas Brezger,
+Nadja Klein, Thomas Kneib, Stefan Lang, Nikolaus Umlauf
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,19 +24,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #ifndef ADMINPARSE
 #define ADMINPARSE
 
-#if defined(BORLAND_OUTPUT_WINDOW)
-#include <vcl.h>
-#pragma hdrstop
-
-#include "StatReview.h"
-#include<StatwinFrame.h>
-#include<statwin_haupt.h>
-
-#elif defined(JAVA_OUTPUT_WINDOW)
-#include<jni.h>
-#endif
-
-//#include <vcl.h>
 #if !defined(__BUILDING_GNU)
 #include <FileCtrl.hpp>
 #include<dir.h>
