@@ -864,14 +864,14 @@ void FULLCOND_kriging::compute_knots(const vector<double> & xvals,
                             // zum Kandidaten wird (ohne Beitrag des neuen Knotens)
 
     int swapindex;                        // Index des zu tauschenden Kandidaten
-                                          // (Kandidat mit dem minimalen Kriterium beim Loop ber den aktuellen Knoten)
+                                          // (Kandidat mit dem minimalen Kriterium beim Loop ueber den aktuellen Knoten)
 
-    double covcritold=0; // Coverage-Kriterium (ndert sich nur nach Durchlauf ber Knoten)
-    double covcritnew=-1;   // Neues Coverage-Kriterium (ndert sich nur nach Durchlauf ber Knoten)
-    double covcritoldi;  // Coverage-Kriterium vorm Swappen von Knoten i (ndert sich nach jedem Swap)
-    double covcritnewi;  // Neues Coverage-Kriterium beim Swappen von Knoten i (ndert sich nach jedem Swap)
+    double covcritold=0; // Coverage-Kriterium (aendert sich nur nach Durchlauf ueber Knoten)
+    double covcritnew=-1;   // Neues Coverage-Kriterium (aendert sich nur nach Durchlauf ueber Knoten)
+    double covcritoldi;  // Coverage-Kriterium vorm Swappen von Knoten i (aendert sich nach jedem Swap)
+    double covcritnewi;  // Neues Coverage-Kriterium beim Swappen von Knoten i (aendert sich nach jedem Swap)
 
-    // Startdesign und Kandidaten zufllig bestimmen
+    // Startdesign und Kandidaten zufaellig bestimmen
 
     datamatrix u(nrdiffobs,1,0);
     statmatrix<int> ind(nrdiffobs,1,0);
@@ -975,10 +975,10 @@ void FULLCOND_kriging::compute_knots(const vector<double> & xvals,
 
         for(j=0; j<nrcand; j++)
           {
-          // Loop ber die Kandidaten. Jeweil das Coverage-Kriterium bei Swap i vs. j ausrechnen
+          // Loop ueber die Kandidaten. Jeweil das Coverage-Kriterium bei Swap i vs. j ausrechnen
           // und gegebenenfalls swapindex umsetzen.
           covcritnewi = 0;
-          // Loopen ber Zeilensummen ohne j
+          // Loopen ueber Zeilensummen ohne j
           for(k=0; k<j; k++)
             {
             covcritnewi += pow(rowsumswithouti(k,0) +
